==> lirc_0.8.2.orig.tar.gz: lirc-0.8.2/daemons/hw_usbx.h <==
/*****************************************************************************
 ** hw_usbx.h ****************************************************************
 *****************************************************************************
 *
 * Copyright (C) 2007 Jelle Foks <jelle@foks.8m.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef HW_USBX_H
#define HW_USBX_H

#include "drivers/lirc.h"

int     usbx_decode                  (struct ir_remote   *remote,
				      ir_code            *prep,
				      ir_code            *codep,
				      ir_code            *postp,
				      int                *repeat_flagp,
				      lirc_t             *remaining_gapp);
int     usbx_init                    (void);
int     usbx_deinit                  (void);
char    *usbx_rec                    (struct ir_remote   *remotes);

#endif

==> lirc_0.8.6.orig.tar.gz: lirc-0.8.6/daemons/hw_usbx.h <==
/*****************************************************************************
 ** hw_usbx.h ****************************************************************
 *****************************************************************************
 *
 * Copyright (C) 2007 Jelle Foks <jelle@foks.8m.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef HW_USBX_H
#define HW_USBX_H

#include "drivers/lirc.h"

int     usbx_decode                  (struct ir_remote   *remote,
				      ir_code            *prep,
				      ir_code            *codep,
				      ir_code            *postp,
				      int                *repeat_flagp,
				      lirc_t             *min_remaining_gapp,
				      lirc_t             *max_remaining_gapp);
int     usbx_init                    (void);
int     usbx_deinit                  (void);
char    *usbx_rec                    (struct ir_remote   *remotes);

#endif
